@@ -10,6 +10,7 @@ mod error;
 mod multipart;
 mod oauth_scopes;
 mod object;
+mod oneof;
 mod request;
 mod response;
 mod security_scheme;
@@ -37,6 +38,15 @@ pub fn derive_enum(input: TokenStream) -> TokenStream {
     }
 }
 
+#[proc_macro_derive(OneOf, attributes(oai))]
+pub fn derive_oneof(input: TokenStream) -> TokenStream {
+    let args = parse_macro_input!(input as DeriveInput);
+    match oneof::generate(args) {
+        Ok(stream) => stream.into(),
+        Err(err) => err.write_errors().into(),
+    }
+}
+
 #[proc_macro_derive(ApiResponse, attributes(oai))]
 pub fn derive_response(input: TokenStream) -> TokenStream {
     let args = parse_macro_input!(input as DeriveInput);
